Learn R Programming

rgsepd (version 1.4.2)

IlluminaBodymap: Sample RNA-Seq Counts data

Description

A collection of counts datasets from Illumina Human Bodymap 2.0, one sample each for adipose, blood, heart and skeletal_muscle. Four technical replicates are created by downsampling the original Illumina data. Alignment was performed by Ensembl, so the source of this dataset is ftp://ftp.ensembl.org/pub/release-70/bam/homo_sapiens/genebuild . Each of the four Human Bodymap samples are downsampled four times. Read counts are collected with Bedtools CoverageBed and a RefSeq exon annotation.

Usage

data(IlluminaBodymap)

Arguments

Value

  • A numeric matrix of read-counts from RNA-Seq, measured at transcripts by coverageBed.

source

http://www.ebi.ac.uk/arrayexpress/experiments/E-MTAB-513/

References

Illumina Human Bodymap 2.0. Ensembl etc.

Examples

Run this code
data(IlluminaBodymap)
head(IlluminaBodymap,30)

Run the code above in your browser using DataLab